import React, { useState, useEffect, useRef } from 'react';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import TypingAnimation from './TypingAnimation';
import { getPromptContent } from '../utils/promptContent';
import { Plus, Send, Upload } from 'lucide-react';
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from './ui/select';

interface ChatInterfaceProps {
  onPromptSelect: (prompt: string, content: any) => void;
  isExpanded: boolean;
  onStartNewChat?: () => void;
}

const prompts = [
  "What can you help me with?",
  "What is MCP?",
  "Who is this for?",
  "Show me how I can earn"
];

const ChatInterface: React.FC<ChatInterfaceProps> = ({ onPromptSelect, isExpanded }) => {
  const [messages, setMessages] = useState<Array<{ text: string; isUser: boolean; isTyping?: boolean }>>([]);
  const [inputValue, setInputValue] = useState('');
  const [isThinking, setIsThinking] = useState(false);
  const [chatKey, setChatKey] = useState(0);
  const scrollAnchorRef = useRef<HTMLDivElement | null>(null);

  const handlePromptClick = (prompt: string) => {
    setMessages(prev => [...prev, { text: prompt, isUser: true }]);
    setIsThinking(true);
    
    setTimeout(() => {
      setIsThinking(false);
      setMessages(prev => [...prev, { text: `Let me show you detailed information about "${prompt}"`, isUser: false, isTyping: true }]);
      
      setTimeout(() => {
        const content = getPromptContent(prompt);
        onPromptSelect(prompt, content);
      }, 1500);
    }, 1000);
  };

  const handleSendMessage = () => {
    if (!inputValue.trim()) return;
    const prompt = inputValue;
    setInputValue('');
    handlePromptClick(prompt);
  };

  const handleKeyPress = (e: React.KeyboardEvent) => {
    if (e.key === 'Enter') handleSendMessage();
  };


  useEffect(() => {
    const handleLeftSidebarPrompt = (event: CustomEvent) => {
      handlePromptClick(event.detail.prompt);
    };
    window.addEventListener('leftSidebarPrompt' as any, handleLeftSidebarPrompt);
    return () => {
      window.removeEventListener('leftSidebarPrompt' as any, handleLeftSidebarPrompt);
    };
  }, []);

  useEffect(() => {
    if (scrollAnchorRef.current) {
      scrollAnchorRef.current.scrollIntoView({ behavior: 'smooth', block: 'end' });
    }
  }, [messages, isThinking]);

  return (
    <div className="flex flex-col h-screen max-h-screen overflow-hidden p-6">
      {/* Hero Section */}
      {messages.length === 0 && (
        <div className={`flex-1 flex flex-col justify-center items-center text-center transition-all duration-500 ${
          isExpanded ? 'max-w-4xl mx-auto' : 'max-w-2xl mx-auto'
        }`}>
          <div className="mb-8">
            <h1 className="text-2xl md:text-6xl text-gray-900 dark:text-white mb-6 leading-tight">
              Build an MCP server and become <span className='text-gray-700 dark:text-gray-300'>a part of the new world.</span>
            </h1>
            <p className="text-lg text-gray-600 dark:text-gray-300 mb-8">
              Where AI chatbots are the modern interface.
            </p>
          </div>
          <div className="w-full max-w-2xl p-8 rounded-2xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10">
            <h3 className="text-lg font-medium text-gray-900 dark:text-white mb-6">
              How can I help you today?
            </h3>
            <div className="grid grid-cols-1 md:grid-cols-2 gap-3">
              {prompts.map((prompt, index) => (
                <Button
                  key={index}
                  variant="ghost"
                  onClick={() => handlePromptClick(prompt)}
                  className="p-4 h-auto text-left justify-start border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-sm bg-white/5 dark:bg-black/5 hover:bg-white/10 dark:hover:bg-black/10 rounded-xl transition-all duration-300 hover:scale-[1.02]"
                >
                  <span className="text-gray-700 dark:text-gray-300 text-sm">{prompt}</span>
                </Button>
              ))}
            </div>
          </div>
        </div>
      )}

      {/* Chat Messages */}
      {messages.length > 0 && (
        <div className="flex-1 w-full md:w-1/2 mx-auto mb-6 overflow-hidden">
          <div
            className="h-full overflow-y-auto space-y-4 scrollbar-hide pr-2"
            ref={scrollAnchorRef}
          >
            {messages.map((message, index) => (
              <div
                key={index}
                className={`flex ${message.isUser ? 'justify-end' : 'justify-start'}`}
              >
                <div
                  className={`max-w-xs lg:max-w-md px-4 py-3 rounded-2xl ${
                    message.isUser
                      ? 'dark:bg-gray-100/20 bg-gray-700/20 backdrop-blur-xl text-gray-900 dark:text-white'
                      : 'border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10 text-gray-900 dark:text-white'
                  }`}
                >
                  {message.isTyping ? (
                    <TypingAnimation text={message.text} />
                  ) : (
                    message.text
                  )}
                </div>
              </div>
            ))}
            {isThinking && (
              <div className="flex justify-start">
                <div className="max-w-xs lg:max-w-md px-4 py-3 rounded-2xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10 text-gray-900 dark:text-white">
                  <div className="flex items-center space-x-2">
                    <div className="flex space-x-1">
                      <div className="w-2 h-2 bg-gray-400 rounded-full animate-bounce"></div>
                      <div className="w-2 h-2 bg-gray-400 rounded-full animate-bounce" style={{ animationDelay: '0.1s' }}></div>
                      <div className="w-2 h-2 bg-gray-400 rounded-full animate-bounce" style={{ animationDelay: '0.2s' }}></div>
                    </div>
                    <span className="text-sm">Hmm good question...</span>
                  </div>
                </div>
              </div>
            )}
            {/* Anchor stays inside this container */}
            <div ref={scrollAnchorRef} />
          </div>
        </div>
      )}

      {/* Input Area */}
      <div className="w-full md:w-1/2 mx-auto border border-gray-200 dark:border-gray-700 backdrop-blur-xl bg-white/10 dark:bg-black/10 rounded-2xl px-4 py-3 space-y-3 pointer-events-auto">
        {/* First Line: Text Input */}
        <Input
          value={inputValue}
          onChange={(e) => setInputValue(e.target.value)}
          onKeyDown={handleKeyPress}
          placeholder="Ask me anything about MCP..."
          className="border-0 bg-transparent focus:outline-none focus:ring-0 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
        />

        {/* Second Line: Dropdown + Upload + Send */}
        <div className="flex items-center justify-between">
          <div className="flex items-center gap-2">
            {/* Dropdown */}
            <Select>
              <SelectTrigger className="w-[100px] h-9 bg-white/20 dark:bg-black/20 border-0 text-sm text-gray-900 dark:text-white">
                <SelectValue placeholder="GPT-4.1" />
              </SelectTrigger>
              <SelectContent>
                <SelectItem value="one">GPT-4o</SelectItem>
                <SelectItem value="two">o3 Mini</SelectItem>
                <SelectItem value="three">Gemini 2.5 Flash</SelectItem>
              </SelectContent>
            </Select>

            {/* Upload Icon */}
            <Button
              type="button"
              variant="ghost"
              size="icon"
              className="p-2 rounded-full hover:bg-gray-300 dark:hover:bg-gray-700 text-gray-900 dark:text-white"
              aria-label="Upload"
            >
              <Plus className="w-5 h-5" />
            </Button>
          </div>

          {/* Send Button */}
          <Button
            onClick={handleSendMessage}
            disabled={!inputValue.trim()}
            className="h-10 w-10 flex items-center justify-center bg-gray-800 hover:bg-gray-900 dark:bg-gray-700 dark:hover:bg-gray-600 rounded-full text-white disabled:opacity-50 cursor-pointer disabled:cursor-not-allowed"
            aria-label="Send"
          >
            <Send className="w-4 h-4" />
          </Button>
        </div>
      </div>
    </div>
  );
};

export default ChatInterface;
