import React, { useState } from 'react';
import Header from '../components/Header';
import ChatInterface from '../components/ChatInterface';
import SidebarPanel from '../components/SidebarPanel';
import LeftSidebar from '../components/LeftSidebar';
import { ThemeProvider } from '../contexts/ThemeContext';
import { getPromptContent } from '../utils/promptContent';
import { FiInfo } from 'react-icons/fi'; // Add this import
import HeroSection from '@/components/HeroSection';
import MCPSection from '@/components/MCPSection';
import MonetizeSection from '@/components/MonetizeSection';

const Index = () => {
  const [selectedPrompt, setSelectedPrompt] = useState<string | null>(null);
  const [sidebarContent, setSidebarContent] = useState<any>(null);
  const [chatKey, setChatKey] = useState(0);

  const handleStartNewChat = () => {
    setChatKey(prev => prev + 1); // This will remount ChatInterface and reset its state
    setSelectedPrompt(null);
    setSidebarContent(null);
  };

  const handlePromptSelect = (prompt: string, content?: any) => {
    setSelectedPrompt(prompt);
    // Get content if not provided (for left sidebar clicks)
    const promptContent = content || getPromptContent(prompt);
    setSidebarContent(promptContent);
  };

  const handleCloseSidebar = () => {
    setSelectedPrompt(null);
    setSidebarContent(null);
  };

  // Add a default info content if needed
  const defaultInfoContent = {
    title: "Chatbot Side Panel",
    description: "Welcome to MCP Verse Spark! Here you can chat with our AI, explore features, and learn more about MCP."
  };

  return (
    <ThemeProvider>
      <div className="bg-gradient-to-br from-white via-gray-50 to-gray-100 dark:from-black dark:via-black dark:to-black transition-all duration-500">
        {/* <Header /> */}
        
        {/* CHAT INTERFACE */}
        <div className="flex h-[calc(100vh-80px)] relative">
          {/* Left Sidebar */}
          <LeftSidebar onPromptSelect={handlePromptSelect} onStartNewChat={handleStartNewChat} />

          {/* Main Chat Interface */}
          <div className={`transition-all duration-500 ease-in-out ${
            selectedPrompt ? 'w-1/2 ml-0' : 'w-full ml-0'
          }`}>
            <ChatInterface 
              key={chatKey} // Add key to force remount on new chat
              onPromptSelect={handlePromptSelect}
              isExpanded={!selectedPrompt}
            />
          </div>

          {/* Sidebar Open Icon */}
          {!selectedPrompt && (
            <button
              onClick={() => handlePromptSelect('info', defaultInfoContent)}
              className="fixed top-24 right-4 z-50 w-10 h-10 rounded-xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-md bg-white/80 dark:bg-black/80 hover:bg-white/90 dark:hover:bg-black/90 transition-all duration-300 shadow-lg flex items-center justify-center"
              aria-label="Open Info Sidebar"
            >
              <FiInfo className="w-5 h-5 text-gray-700 dark:text-gray-200" />
            </button>
          )}

          {/* Right Sliding Sidebar Panel */}
          <SidebarPanel 
            isOpen={!!selectedPrompt}
            content={sidebarContent}
            onClose={handleCloseSidebar}
          />
        </div>

        {/* Subtle light leaks */}
        {/* <div className="fixed inset-0 pointer-events-none overflow-hidden">
          <div className="absolute -top-1/2 -right-1/2 w-full h-full bg-gradient-radial from-blue-500/5 via-transparent to-transparent dark:from-blue-400/10"></div>
          <div className="absolute -bottom-1/2 -left-1/2 w-full h-full bg-gradient-radial from-purple-500/5 via-transparent to-transparent dark:from-purple-400/10"></div>
        </div> */}

        {/* Authentic light leaks with warmth and blur */}
        {/* <div className="fixed inset-0 pointer-events-none overflow-hidden z-0">
          <div className="absolute top-[10%] left-[5%] w-[300px] h-[300px] bg-red-400 opacity-20 rounded-full mix-blend-screen blur-3xl animate-pulse-slow" />
          <div className="absolute bottom-[15%] right-[10%] w-[250px] h-[250px] bg-yellow-300 opacity-15 rounded-full mix-blend-screen blur-2xl animate-pulse-slower" />
          <div className="absolute top-[30%] right-[20%] w-[200px] h-[200px] bg-pink-400 opacity-10 rounded-full mix-blend-screen blur-3xl animate-pulse" />
          <div className="absolute bottom-[20%] left-[25%] w-[280px] h-[280px] bg-orange-300 opacity-20 rounded-full mix-blend-screen blur-2xl animate-pulse" />
        </div> */}

        {/* Realistic Film Camera Light Leaks */}
        <div className="fixed inset-0 pointer-events-none overflow-hidden z-0">
          {/* Horizontal streak from left */}
          <div className="absolute left-0 top-1/4 w-[600px] h-[200px] bg-gradient-to-r from-red-400/30 via-orange-300/20 to-transparent blur-3xl rotate-[-5deg] skew-y-6 mix-blend-screen" />

          {/* Vertical burn from bottom */}
          <div className="absolute bottom-0 left-1/3 w-[300px] h-[580px] bg-gradient-to-t from-yellow-300/20 via-pink-400/10 to-transparent blur-3xl rotate-12 mix-blend-screen" />

          {/* Angled streak from top right */}
          <div className="absolute top-0 right-0 w-[400px] h-[300px] bg-gradient-to-bl from-red-500/20 via-orange-300/10 to-transparent blur-2xl -rotate-12 mix-blend-screen" />

          {/* Blobby irregular light spot */}
          <div className="absolute bottom-[10%] right-[20%] w-[350px] h-[250px] bg-pink-300/15 rounded-3xl blur-[100px] rotate-[18deg] mix-blend-screen" />
        </div>
        

        <HeroSection />
        <MCPSection />
        <MonetizeSection />

      </div>
    </ThemeProvider>
  );
};

export default Index;
